/*
 * *****************************************************************************************
 *
 *         Copyright (C) 2014-2021 Gowin Semiconductor Technology Co.,Ltd.
 * 
 * @file        command_responder.c
 * @author      Embedded Development Team
 * @version     V1.0.0
 * @date        2021-03-24 09:00:00
 * @brief       command responder.
 ******************************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "GOWIN_M1.h"
#include "command_responder.h"
#include "mjb_define.h"
#include <stdbool.h>

/* Variables ------------------------------------------------------------------*/
bool run_flag = true;

/* Functions ------------------------------------------------------------------*/
void command_responder(int8_t* image, uint32_t* infer_num)
{
  //GoAI indicator
  //image[0] : no person
  //image[1] : person
  //LED2~4(mjb board) and LED1~4(camera board) on : person
  //LED2~4(mjb board) and LED1~4(camera board) off : no person
  //HDMI
  //UART
  if (image[0]<image[1])
  {
    //person
    #ifdef BACKEND_LED_OUT
    //LED2~4(mjb board) on
    //LED1~4(camera board) on
    GPIO_ResetBit(GPIO0, GPIO_Pin_1);
    GPIO_ResetBit(GPIO0, GPIO_Pin_2);
    GPIO_ResetBit(GPIO0, GPIO_Pin_3);
    GPIO_ResetBit(GPIO0, GPIO_Pin_4);
    GPIO_ResetBit(GPIO0, GPIO_Pin_5);
    GPIO_ResetBit(GPIO0, GPIO_Pin_6);
    GPIO_ResetBit(GPIO0, GPIO_Pin_7);
    #endif

    #ifdef BACKEND_HDMI_OUT
    //HDMI : person
    *infer_num = 0xC;
    #endif

    #ifdef BACKEND_UART_OUT
    //UART0
    UART_SendString(UART0, "\r\n***** UART Outputs : Person *****\r\n");
    #endif
  }
  else
  {
    //no person
    #ifdef BACKEND_LED_OUT
    //LED2~4(mjb board) off
    //LED1~4(camera board) off
    GPIO_SetBit(GPIO0, GPIO_Pin_1);
    GPIO_SetBit(GPIO0, GPIO_Pin_2);
    GPIO_SetBit(GPIO0, GPIO_Pin_3);
    GPIO_SetBit(GPIO0, GPIO_Pin_4);
    GPIO_SetBit(GPIO0, GPIO_Pin_5);
    GPIO_SetBit(GPIO0, GPIO_Pin_6);
    GPIO_SetBit(GPIO0, GPIO_Pin_7);
    #endif

    #ifdef BACKEND_HDMI_OUT
    //HDMI : empty no person
    *infer_num = 0;
    #endif

    #ifdef BACKEND_UART_OUT
    //UART0
    UART_SendString(UART0, "\r\n***** UART Outputs : No Person *****\r\n");
    #endif
  }

  //System indicator
  //LED1(mjb board) blinks each inference
  if(run_flag)
  {
    GPIO_ResetBit(GPIO0, GPIO_Pin_0);
  }
  else
  {
    GPIO_SetBit(GPIO0, GPIO_Pin_0);
  }
  run_flag = !run_flag;
}
